- data
a numeric vector of data values.
- method
a character string. Different transformation methods can be used for the estimation of the optimal transformation parameter: Box-Cox ("bc"), Log-shift ("ls"), Bickel-Doksum ("bd"), Yeo-Johnson ("yj"), Square Root ("ss"), Manly ("mn"), Modulus ("md"), Dual ("dl"), Gpower ("gp"), Log ("lg"), Glog ("gl"), Neglog ("nl"), Reciprocal ("rp"). Default is set to method = "dl".
- lambda
a vector which includes the sequence of candidate lambda values. Please see the corresponding method to learn the lambda range. Default is set to (0,6) with increment 0.01.
- lambda2
a numeric for an additional shifting parameter. Please see the corresponding method to learn the lambda2. Default is set to lambda2 = NULL.
- plot
a logical to plot histogram with its density line and qqplot of raw and transformed data. Defaults plot = TRUE.
- alpha
the level of significance to check the normality after transformation. Default is set to alpha = 0.05.
- verbose
a logical for printing output to R console.